/*
 *  XMail by Davide Libenzi ( Intranet and Internet mail server )
 *  Copyright (C) 1999,...,2002  Davide Libenzi
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Davide Libenzi <davidel@xmailserver.org>
 *
 */


#ifndef _SVRCONFIG_H
#define _SVRCONFIG_H



///////////////////////////////////////////////////////////////////////////////
// Setup for the use of Maildir mailbox delivery
///////////////////////////////////////////////////////////////////////////////
#if defined(__LINUX__) || defined(__SOLARIS__) || defined(__FREEBSD__)
#define CONFIG_MAILDIR
#endif          // #if defined(__LINUX__) || defined(__SOLARIS__) || defined(__FREEBSD__)





#endif
